@@ -1,10 +1,14 @@
-from typing import Union
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Union
 
 import altair as alt
 import numpy as np
-import pandas as pd
 import xarray as xr
 
+if TYPE_CHECKING:
+    import pandas as pd
+
 
 def _standardize_data(source: Union[pd.DataFrame, xr.Dataset],
                       z: str = 'time') -> pd.DataFrame:
@@ -82,30 +86,30 @@ def alt_line_chart(source: Union[pd.DataFrame, xr.Dataset],
         x=f'{x}:Q', y=f'{y}:Q', color=alt.Color('run:N'), tooltip='run')
 
     if max_slider != 0:
-        slider = alt.binding_range(name='Time index',
+        slider = alt.binding_range(name=f'{z} index',
                                    min=0,
                                    max=max_slider,
                                    step=1)
-        select_step = alt.selection_single(name=z,
-                                           fields=['slider'],
-                                           bind=slider,
-                                           init={'slider': 0})
-        line = line.add_selection(select_step).transform_filter(
+        select_step = alt.selection_point(name=z,
+                                          fields=['slider'],
+                                          bind=slider,
+                                          value=0)
+        line = line.add_params(select_step).transform_filter(
             select_step).interactive()
         if std:
             band = band.transform_filter(select_step).interactive()
 
         first_run = source.iloc[0].run
-        slider = alt.binding_range(name='Reference time index',
+        slider = alt.binding_range(name=f'Reference {z} index',
                                    min=0,
                                    max=max_slider,
                                    step=1)
-        select_step = alt.selection_single(name='reference',
-                                           fields=['slider'],
-                                           bind=slider,
-                                           init={'slider': 0})
+        select_step = alt.selection_point(name='reference',
+                                          fields=['slider'],
+                                          bind=slider,
+                                          value=0)
 
-        ref = ref.add_selection(select_step).transform_filter(
+        ref = ref.add_params(select_step).transform_filter(
             select_step).transform_filter(
                 alt.datum.run == first_run).interactive()
 
@@ -169,27 +173,27 @@ def alt_errorband_chart(source: Union[pd.DataFrame, xr.Dataset],
 
     if max_slider != 0:
         slider = alt.binding_range(min=0, max=max_slider, step=1)
-        select_step = alt.selection_single(name=z,
-                                           fields=['slider'],
-                                           bind=slider,
-                                           init={'slider': 0})
+        select_step = alt.selection_point(name=z,
+                                          fields=['slider'],
+                                          bind=slider,
+                                          value=0)
 
-        line = line.add_selection(select_step).transform_filter(
+        line = line.add_params(select_step).transform_filter(
             select_step).interactive()
-        band = band.add_selection(select_step).transform_filter(
+        band = band.add_params(select_step).transform_filter(
             select_step).interactive()
 
-        slider = alt.binding_range(name='Reference time index',
+        slider = alt.binding_range(name=f'Reference {z} index',
                                    min=0,
                                    max=max_slider,
                                    step=1)
 
-        select_step = alt.selection_single(name='reference',
-                                           fields=['slider'],
-                                           bind=slider,
-                                           init={'slider': 0})
+        select_step = alt.selection_point(name='reference',
+                                          fields=['slider'],
+                                          bind=slider,
+                                          value=0)
 
-        ref = ref.add_selection(select_step).transform_filter(
+        ref = ref.add_params(select_step).transform_filter(
             select_step).interactive()
 
     return line + band + ref
