@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import functools
 import logging
 from datetime import datetime
@@ -9,10 +11,13 @@ import click
 from pydantic import ValidationError
 
 from ._click_opt_groups import GroupCmd, GroupOpt
-from ._logging_utils import TermEscapeCodeFormatter, duqlog_screen
-from .config import cfg
+from ._logging_utils import TermEscapeCodeFormatter, duqlog_screen, initialize_duqlog_screen
+from .config import CFG, load_config
 from .operations import op_queue, op_queue_context
 
+logging.basicConfig(level=logging.INFO)
+initialize_duqlog_screen()
+
 logger = logging.getLogger(__name__)
 
 try:
@@ -152,26 +157,28 @@ class OptionParser:
             fhandler.setFormatter(escaped_format)
             logging.getLogger().addHandler(fhandler)
 
+        start_time = datetime.now().astimezone().strftime(
+            '%Y-%m-%d %H:%M:%S %z')
         logger.info('')
-        logger.info(
-            'Duqtools starting at '
-            f'{datetime.now().astimezone().strftime("%Y-%m-%d %H:%M:%S %z")}')
+        logger.info(f'Duqtools starting at {start_time}')
         logger.info('------------------------------------------------')
         logger.info('')
 
     def parse_quiet(self, *, quiet, **kwargs):
         if quiet:
             duqlog_screen.handlers = []  # remove output methods
-            cfg.quiet = True
+            CFG.quiet = True
 
     def parse_dry_run(self, *, dry_run, **kwargs):
         op_queue.dry_run = dry_run
 
     def parse_config(self, *, config, **kwargs):
         try:
-            cfg.parse_file(config)
+            load_config(config)
         except ValidationError as e:
             exit(e)
+        except FileNotFoundError as e:
+            exit(e)
 
     def parse_yes(self, *, yes, **kwargs):
         op_queue.yes = yes
@@ -261,12 +268,16 @@ def cli_setup(**kwargs):
 @click.option('--force',
               is_flag=True,
               help='Overwrite existing run directories and IDS data.')
+@click.option('--no-sampling',
+              is_flag=True,
+              help='Create base run (ignores `dimensions`/`sampler`).')
 @common_options(*all_options)
 def cli_create(**kwargs):
-    """Create the UQ run files."""
+    """Read duqtools.yaml and create the new IMAS data files from template
+    data."""
     from .create import create
     with op_queue_context():
-        create(**kwargs)
+        create(cfg=CFG, **kwargs)
 
 
 @cli.command('recreate', cls=GroupCmd)
@@ -282,29 +293,34 @@ def cli_recreate(**kwargs):
     """
     from .create import recreate
     with op_queue_context():
-        recreate(**kwargs)
+        recreate(cfg=CFG, **kwargs)
 
 
 @cli.command('submit', cls=GroupCmd)
 @click.option('--force',
               is_flag=True,
               help='Re-submit running or completed jobs.')
-@click.option(
-    '--schedule',
-    is_flag=True,
-    help='Schedule and submit jobs automatically. `max_jobs` must be defined.')
-@click.option(
-    '-j',
-    '--max_jobs',
-    type=int,
-    help=
-    'Maximum number of jobs to submit (simultaneously for array submission).')
+@click.option('--schedule',
+              is_flag=True,
+              help=('Schedule and submit jobs automatically.'))
+@click.option('-j',
+              '--max_jobs',
+              type=int,
+              help='Maximum number of jobs running simultaneously.',
+              default=10)
 @click.option(
     '--max_array_size',
     type=int,
     default=100,
     help='Maximum array size for slurm (usually 1001, default = 100).')
-@click.option('-a', '--array', is_flag=True, help='Submit jobs as array.')
+@click.option('-a', '--array', is_flag=True, help=('Submit jobs as array. '))
+@click.option('--array-script',
+              is_flag=True,
+              help=('Create script to submit jobs as array. '
+                    'Like --array, but does not submit.'))
+@click.option('--limit',
+              type=int,
+              help=('Limits total number of jobs to submit.'))
 @click.option('-r',
               '--resubmit',
               multiple=True,
@@ -319,18 +335,37 @@ def cli_recreate(**kwargs):
               help='Only submit jobs with this status.')
 @common_options(*all_options)
 def cli_submit(**kwargs):
-    """Submit the UQ runs.
+    """Submit system runs to job management system.
 
-    This subcommand will read `runs.yaml`, and start all runs which are not yet
-    running. By default, It will not re-submit running or finished jobs.
+    This subcommand will read `runs.yaml`, and start all runs which are
+    not yet running. By default, It will not re-submit running or
+    finished jobs.
 
-    There is a scheduler that will continue to submit jobs until the specified
-    maximum number of jobs is running. Once a job has completed, a new job will
-    be submitted from the queue to fill the spot.
+    There is a scheduler that will continue to submit jobs until the
+    specified maximum number of jobs is running. Once a job has
+    completed, a new job will be submitted from the queue to fill the
+    spot.
     """
     from .submit import submit
     with op_queue_context():
-        submit(**kwargs)
+        submit(cfg=CFG, **kwargs)
+
+
+@cli.command('sync_prominence', cls=GroupCmd)
+@click.option('--force', is_flag=True, help='Overwrite data if necessary')
+@common_options(*all_options)
+def cli_sync_prominence(**kwargs):
+    """Sync data back from prominence.
+
+    This subcommand is meant to be used in combination with the
+    prominence submission system. After the jobs are completed on
+    prominence this command can be used to retrieve and extract the
+    completed runs from prominence to the local machine, so that they
+    can be used in further analysis.
+    """
+    from .sync_prominence import sync_prominence
+    with op_queue_context():
+        sync_prominence(cfg=CFG, **kwargs)
 
 
 @cli.command('status', cls=GroupCmd)
@@ -338,9 +373,9 @@ def cli_submit(**kwargs):
 @click.option('--progress', is_flag=True, help='Fancy progress bar')
 @common_options(*all_options)
 def cli_status(**kwargs):
-    """Print the status of the UQ runs."""
+    """Print the status of the system runs."""
     from .status import status
-    status(**kwargs)
+    status(cfg=CFG, **kwargs)
 
 
 @cli.command('plot')
@@ -360,7 +395,7 @@ def cli_status(**kwargs):
 @datafile_option
 @common_options(*logging_options)
 def cli_plot(**kwargs):
-    """Plot some IDS data.
+    """Generate plots for IMAS data.
 
     \b
     Examples:
@@ -385,7 +420,7 @@ def cli_clean(**kwargs):
     """Delete generated IDS data and the run dir."""
     from .cleanup import cleanup
     with op_queue_context():
-        cleanup(**kwargs)
+        cleanup(cfg=CFG, **kwargs)
 
 
 @cli.command('go', cls=GroupCmd)
@@ -401,9 +436,10 @@ def cli_go(**kwargs):
     from .status import status
     from .submit import submit
     with op_queue_context():
-        create(**kwargs)
+        create(cfg=CFG, **kwargs)
     with op_queue_context():
-        submit(max_jobs=None,
+        submit(cfg=CFG,
+               max_jobs=None,
                array=True,
                schedule=None,
                resubmit=tuple(),
@@ -412,7 +448,7 @@ def cli_go(**kwargs):
     skwargs = kwargs.copy()
     skwargs['detailed'] = True
     skwargs['progress'] = False
-    status(**skwargs)
+    status(cfg=CFG, **skwargs)
 
     dash(**kwargs)
 
@@ -487,14 +523,19 @@ def cli_merge(**kwargs):
 
 @cli.command('list-variables')
 @config_option
-def cli_list_variables(**kwargs):
+def cli_list_variables(config, **kwargs):
     """List available variables.
 
-    Picks up variables from `duqtools.yaml` if it exists in the local
+    This also picks up variables from `duqtools.yaml` if it exists in the local
     directory.
     """
     from .list_variables import list_variables
-    list_variables(**kwargs)
+    try:
+        cfg = load_config(config)
+    except FileNotFoundError:
+        print(f'Cannot find `{config}`.')
+        cfg = CFG
+    list_variables(cfg=cfg, **kwargs)
 
 
 @cli.command('version')
@@ -509,10 +550,10 @@ def cli_version(**kwargs):
     try:
         repo = git.Repo(Path(__file__), search_parent_directories=True)
         sha = repo.head.object.hexsha
-    except OSError:
-        pass
-    else:
-        string += f' (rev: {sha})'
+    except BaseException:
+        sha = '???'
+
+    string += f' (rev: {sha})'
 
     click.echo(string)
 
