@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import logging
 import shutil
 import warnings
@@ -5,15 +7,16 @@ from pathlib import Path
 from typing import Any, Sequence
 
 import pandas as pd
+from pydantic_yaml import to_yaml_file
 
 from .apply_model import apply_model
 from .cleanup import remove_run
-from .config import Config, cfg
+from .config import Config
 from .ids import ImasHandle
 from .matrix_samplers import get_matrix_sampler
-from .models import Locations, Run, Runs
+from .models import Job, Locations, Run, Runs
 from .operations import add_to_op_queue, op_queue
-from .system import get_system
+from .systems import get_system
 
 logger = logging.getLogger(__name__)
 
@@ -27,68 +30,88 @@ class CreateError(Exception):
 class CreateManager:
     """Docstring for CreateManager."""
 
-    def __init__(self):
-        self.options = cfg.create
-
-        if not self.options:
+    def __init__(self, cfg: Config):
+        self.cfg = cfg
+        if not self.cfg.create:
             logger.warning('No create options specified.')
             raise CreateError('No create options specified in config.')
 
+        self.options = self.cfg.create
+
         self.template_drc = self.options.template
-        self.system = get_system()
+        self.system = get_system(cfg=cfg)
         self.runs_dir = self.system.get_runs_dir()
         self.source = self._get_source_handle()
 
-        locations = Locations()
+        locations = Locations(cfg=cfg)
         self.runs_yaml = locations.runs_yaml
         self.data_csv = locations.data_csv
 
     def _get_source_handle(self) -> ImasHandle:
-        if not self.options.template_data:
+        template_data = self.options.template_data
+
+        if not template_data:
+            if not self.template_drc:
+                raise ValueError('Missing `create.template`')
             source = self.system.imas_from_path(self.template_drc)
         else:
-            source = ImasHandle.parse_obj(self.options.template_data)
+            source = ImasHandle.model_validate(template_data,
+                                               from_attributes=True)
 
         logger.info('Source data: %s', source)
 
         return source
 
-    def generate_ops_list(self) -> list[Any]:
+    def get_base_ops(self) -> list[Any]:
+        """Generate base operations that are always applied."""
+        base_ops = [op.convert() for op in self.options.operations]
+        return base_ops
+
+    def generate_ops_dict(self,
+                          *,
+                          base_only: bool = False) -> dict[str, list[Any]]:
         """Generate set of operations for a run."""
-        dimensions = self.options.dimensions
+        base_ops = self.get_base_ops()
+
+        if base_only:
+            return {'base': base_ops}
+
+        matrix = tuple(model.expand() for model in self.options.dimensions)
         matrix_sampler = get_matrix_sampler(self.options.sampler.method)
-        matrix = tuple(model.expand() for model in dimensions)
-        ops_list = matrix_sampler(*matrix, **dict(self.options.sampler))
 
-        return ops_list
+        sampled_ops_lists = matrix_sampler(*matrix,
+                                           **dict(self.options.sampler))
 
-    def make_run_models(self, ops_list: Sequence[Any],
+        ops_dict = {}
+        for i, ops_list in enumerate(sampled_ops_lists):
+            name = f'{RUN_PREFIX}{i:04d}'
+            ops_dict[name] = [*base_ops, *ops_list]
+
+        return ops_dict
+
+    def make_run_models(self, *, ops_dict: dict[str, list[Any]],
                         absolute_dirpath: bool) -> list[Run]:
         """Take list of operations and create run models."""
         run_models = []
 
-        for i, operations in enumerate(ops_list):
-            dirname = self.runs_dir / f'{RUN_PREFIX}{i:04d}'
+        for name, operations in ops_dict.items():
+            dirname = self.runs_dir / name
 
             data_in = self.system.get_data_in_handle(
                 dirname=dirname,
-                seq_number=i,
                 source=self.source,
-                options=self.options.data,
             )
 
             data_out = self.system.get_data_out_handle(
                 dirname=dirname,
-                seq_number=i,
                 source=self.source,
-                options=self.options.data,
             )
 
             model = Run(dirname=dirname,
-                        shortname=dirname.name,
+                        shortname=name,
                         data_in=data_in,
-                        data_out=data_out,
-                        operations=operations)
+                        data_out=data_out)
+            model.operations = operations  # it bugs out so don't validate
 
             run_models.append(model)
 
@@ -107,7 +130,8 @@ class CreateManager:
         any_exists = False
 
         for model in models:
-            if ImasHandle.parse_obj(model.data_in).exists():
+            if ImasHandle.model_validate(model.data_in,
+                                         from_attributes=True).exists():
                 logger.info('Target %s already exists', model.data_in)
                 op_queue.add_no_op(
                     description='Not creating IDS',
@@ -141,31 +165,32 @@ class CreateManager:
     def apply_operations(self, data_in: ImasHandle, run_dir: Path,
                          operations: list[Any]):
         for model in operations:
-            apply_model(model, run_dir=run_dir, ids_mapping=data_in)
+            apply_model(model,
+                        run_dir=run_dir,
+                        ids_mapping=data_in,
+                        system=self.system)
 
     @add_to_op_queue('Writing runs', '{self.runs_yaml}', quiet=True)
     def write_runs_file(self, runs: Sequence[Run]) -> None:
-        runs = Runs.parse_obj(runs)
+        runs = Runs.model_validate(runs, from_attributes=True)
 
         with warnings.catch_warnings():
             warnings.simplefilter('ignore')
-            with open(self.runs_yaml, 'w') as f:
-                runs.yaml(stream=f)
+            to_yaml_file(self.runs_yaml, runs)
 
             # Only if it is a different directory
             if self._is_runs_dir_different_from_config_dir():
-                with open(self.runs_dir / 'runs.yaml', 'w') as f:
-                    runs.yaml(stream=f)
+                to_yaml_file(self.runs_dir / 'runs.yaml', runs)
 
     @add_to_op_queue('Writing csv', quiet=True)
-    def write_runs_csv(self, runs: Sequence[Run], cfg: Config):
+    def write_runs_csv(self, runs: Sequence[Run]):
         fname = self.data_csv
 
-        prefix = f'{cfg.tag}.' if cfg.tag else ''
+        prefix = f'{self.cfg.tag}.' if self.cfg.tag else ''
 
         run_map = {
-            f'{prefix}{run.shortname}': run.data_out.dict()
-            for run in runs
+            f'{prefix}{run.shortname}': run.data_out.model_dump()
+            for run in runs if run.data_out
         }
         df = pd.DataFrame.from_dict(run_map, orient='index')
         df.to_csv(fname)
@@ -173,11 +198,20 @@ class CreateManager:
         if self._is_runs_dir_different_from_config_dir():
             df.to_csv(self.runs_dir / fname)
 
-    @add_to_op_queue('Storing duqtools.yaml inside runs_dir', quiet=True)
-    def copy_config(self, config):
+    def copy_config(self):
+        if self.cfg._path is None:
+            return
+
         if self._is_runs_dir_different_from_config_dir():
-            shutil.copyfile(Path.cwd() / config,
-                            self.runs_dir / 'duqtools.yaml')
+            op_queue.add(
+                action=shutil.copyfile,
+                args=(
+                    Path.cwd() / self.cfg._path,
+                    self.runs_dir / 'duqtools.yaml',
+                ),
+                description='Copying config to run directory',
+                quiet=True,
+            )
 
     def _is_runs_dir_different_from_config_dir(self) -> bool:
         """Return True if the runs dir is different from the duqtools config
@@ -194,37 +228,54 @@ class CreateManager:
                      description='Creating run',
                      extra_description=f'{model.dirname}')
 
-        self.source.copy_data_to(model.data_in)
+        self.source.copy_data_to(
+            ImasHandle.model_validate(model.data_in, from_attributes=True))
 
-        self.system.copy_from_template(self.template_drc, model.dirname)
+        if self.template_drc:
+            self.system.copy_from_template(self.template_drc, model.dirname)
 
         self.apply_operations(model.data_in, model.dirname, model.operations)
 
-        self.system.write_batchfile(model.dirname, cfg)
+        self.system.write_batchfile(model.dirname)
 
-        self.system.update_imas_locations(run=model.dirname,
-                                          inp=model.data_in,
-                                          out=model.data_out)
+        if model.data_in and model.data_out:
+            self.system.update_imas_locations(run=model.dirname,
+                                              inp=model.data_in,
+                                              out=model.data_out,
+                                              template_drc=self.template_drc)
+        else:
+            raise Exception(
+                'data not present in model, this should not happen')
 
 
-def create(*, force, config, absolute_dirpath: bool = False, **kwargs):
+def create(*,
+           cfg: Config,
+           force: bool = False,
+           no_sampling: bool = False,
+           absolute_dirpath: bool = False,
+           **kwargs) -> list[Run]:
     """Create input for jetto and IDS data structures.
 
     Parameters
     ----------
     force : bool
         Override protection if data and directories already exist.
-    config : Path
-        Config file location
+    cfg : Config
+        Duqtools config
+    no_sampling : bool
+        If true, create base run by ignoring `sampler`/`dimensions`.
 
     **kwargs
         Unused.
     """
-    create_mgr = CreateManager()
+    create_mgr = CreateManager(cfg)
 
-    ops_list = create_mgr.generate_ops_list()
+    ops_dict = create_mgr.generate_ops_dict(base_only=no_sampling)
 
-    runs = create_mgr.make_run_models(ops_list, absolute_dirpath)
+    runs = create_mgr.make_run_models(
+        ops_dict=ops_dict,
+        absolute_dirpath=absolute_dirpath,
+    )
 
     if not force:
 
@@ -236,29 +287,47 @@ def create(*, force, config, absolute_dirpath: bool = False, **kwargs):
 
         if target_exists:
             create_mgr.warn_no_create_runs()
-            return
+            return []
 
     for model in runs:
         create_mgr.create_run(model, force=force)
 
     create_mgr.write_runs_file(runs)
-    create_mgr.write_runs_csv(runs, cfg)
-    create_mgr.copy_config(config)
+    create_mgr.write_runs_csv(runs)
+    create_mgr.copy_config()
+
+    return runs
 
 
-def recreate(*, runs: Sequence[Path], **kwargs):
+def create_api(config: dict, **kwargs) -> dict[str, tuple[Job, Run]]:
+    """Wrapper around create for python api."""
+    cfg = Config.from_dict(config)
+    runs = create(cfg=cfg, **kwargs)
+
+    if len(runs) == 0:
+        raise CreateError('No runs were created, check logs for errors.')
+
+    return {
+        str(run.shortname): (Job(run.dirname, cfg=cfg), run)
+        for run in runs
+    }
+
+
+def recreate(*, cfg: Config, runs: Sequence[Path], **kwargs):
     """Create input for jetto and IDS data structures.
 
     Parameters
     ----------
+    cfg : Config
+        Duqtools config.
     runs : Sequence[Path]
         Run names to recreate.
     **kwargs
         Unused.
     """
-    create_mgr = CreateManager()
+    create_mgr = CreateManager(cfg)
 
-    run_dict = {run.shortname: run for run in Locations().runs}
+    run_dict = {run.shortname: run for run in Locations(cfg=cfg).runs}
 
     run_models = []
     for run in runs:
@@ -266,8 +335,13 @@ def recreate(*, runs: Sequence[Path], **kwargs):
             raise ValueError(f'`{run}` not in `runs.yaml`.')
 
         model = run_dict[run]
-        model.data_in = ImasHandle.parse_obj(model.data_in)
-        model.data_out = ImasHandle.parse_obj(model.data_out)
+        model.data_in = ImasHandle.model_validate(model.data_in,
+                                                  from_attributes=True)
+        assert model.data_in
+
+        model.data_out = ImasHandle.model_validate(model.data_out,
+                                                   from_attributes=True)
+        assert model.data_out
 
         model.data_in.delete()
         remove_run(model)
@@ -276,3 +350,20 @@ def recreate(*, runs: Sequence[Path], **kwargs):
 
     for model in run_models:
         create_mgr.create_run(model)
+
+    return run_models
+
+
+def recreate_api(config: dict, runs: Sequence[Path],
+                 **kwargs) -> dict[str, tuple[Job, Run]]:
+    """Wrapper around create for python api."""
+    cfg = Config.from_dict(config)
+    runs = recreate(cfg=cfg, runs=runs, **kwargs)
+
+    if len(runs) == 0:
+        raise CreateError('No runs were recreated, check logs for errors.')
+
+    return {
+        str(run.shortname): (Job(run.dirname, cfg=cfg), run)
+        for run in runs
+    }
