@@ -1,4 +1,5 @@
 # https://github.com/duqtools/duqtools/issues/27
+from __future__ import annotations
 
 import logging
 
@@ -11,7 +12,7 @@ try:
     import xml.sax.handler
 
     import imas
-    from imas import imasdef
+    from imas import imasdef  # type: ignore
 
     IMAS_PREFIX = os.getenv('IMAS_PREFIX', '')
     PATH_IDSDEF = f'{IMAS_PREFIX}/include/IDSDef.xml'
@@ -55,4 +56,5 @@ except (ModuleNotFoundError, ImportError):
 
     Parser = Mock()  # type: ignore
 
-    logger.warning('Could not import IMAS:', exc_info=True)
+if imas_mocked:
+    logger.info('Could not import IMAS, using mocks instead.')
