@@ -1,13 +1,15 @@
+from __future__ import annotations
+
 from pathlib import Path
 
 import click
 
-from ..config import cfg
+from ..config import load_config
 from ..models import Job, Locations
 from ..status import Status, StatusError
 
 
-def status(*, progress: bool, detailed: bool, **kwargs):
+def status(*, progress: bool, detailed: bool, pattern: str, **kwargs):
     """Show status of nested runs.
 
     Parameters
@@ -16,11 +18,15 @@ def status(*, progress: bool, detailed: bool, **kwargs):
         Show progress bar.
     detailed : bool
         Show detailed progress for every job.
+    pattern : str
+        Show status only for subdirectories matching this glob pattern
     """
+    if pattern is None:
+        pattern = '**'
 
     cwd = Path.cwd()
 
-    config_files = cwd.glob('**/duqtools.yaml')
+    config_files = cwd.glob(f'{pattern}/duqtools.yaml')
 
     all_jobs: list[Job] = []
 
@@ -28,22 +34,25 @@ def status(*, progress: bool, detailed: bool, **kwargs):
     click.echo()
 
     for config_file in config_files:
-        cfg.parse_file(config_file)
+        cfg = load_config(config_file)
 
-        if not cfg.status:
+        if not cfg.system:
             raise StatusError(
                 f'Status field required in config file: {config_file}')
 
         config_dir = config_file.parent
 
-        jobs = [Job(run.dirname) for run in Locations(config_dir).runs]
+        jobs = [
+            Job(run.dirname, cfg=cfg)
+            for run in Locations(parent_dir=config_dir, cfg=cfg).runs
+        ]
         all_jobs.extend(jobs)
 
-        name = config_file.parent.name
+        dirname = config_file.parent.relative_to(cwd)
         tag = cfg.tag
         status = ''.join(job.status_symbol for job in jobs)
 
-        click.echo(f'{name} ({tag}): {status}')
+        click.echo(f'{dirname} ({tag}): {status}')
 
     click.echo()
 
