@@ -1,19 +1,21 @@
 from __future__ import annotations
 
 import logging
-from typing import Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from .config import var_lookup
 from .ids import ImasHandle, merge_data
 from .operations import op_queue
-from .schema import IDSVariableModel
 from .utils import read_imas_handles_from_file
 
+if TYPE_CHECKING:
+    from imas2xarray import Variable
+
 logger = logging.getLogger(__name__)
 info, debug = logger.info, logger.debug
 
 
-def _resolve_variables(var_names: Sequence[str]) -> list[IDSVariableModel]:
+def _resolve_variables(var_names: Sequence[str]) -> Sequence[Variable]:
     """Looks up variables if specified, if empty return all variables."""
     idsvar_lookup = var_lookup.filter_type('IDS-variable')
 
@@ -33,7 +35,7 @@ def _merge(*,
            handles: Sequence[ImasHandle],
            template: ImasHandle,
            target: ImasHandle,
-           variables: Sequence[IDSVariableModel],
+           variables: Sequence[Variable],
            force: bool = False):
     """Merge mas data.
 
@@ -82,8 +84,9 @@ def merge(*, target: str, template: str, handles: list[str],
     variables = _resolve_variables(var_names)
 
     _merge(
-        handles=handles,
-        template=template,
-        target=target,
+        handles=handles,  # type: ignore
+        template=template,  # type: ignore
+        target=target,  # type: ignore
         variables=variables,
+        force=force,
     )
