@@ -1,9 +1,15 @@
-from os import getenv
-from pathlib import Path
-from typing import Optional
+from __future__ import annotations
 
-from ..config import cfg
-from ._run import Run, Runs
+from pathlib import Path
+from typing import TYPE_CHECKING, Optional
+
+from pydantic_yaml import parse_yaml_raw_as
+
+from ._run import Runs
+
+if TYPE_CHECKING:
+    from ..config import Config
+    from ._run import Run
 
 
 class Locations:
@@ -13,11 +19,15 @@ class Locations:
     known config directory.
     """
 
-    def __init__(self, parent_dir: Optional[Path] = None):
+    def __init__(self,
+                 *,
+                 parent_dir: Optional[Path] = None,
+                 cfg: Optional[Config] = None):
         if not parent_dir:
             parent_dir = Path.cwd()
 
         self.parent_dir = parent_dir
+        self.cfg = cfg
 
     @property
     def data_csv(self):
@@ -42,22 +52,7 @@ class Locations:
         if not runs_yaml.exists():
             raise OSError(f'Cannot find {runs_yaml}.')
 
-        return Runs.parse_file(runs_yaml)
+        with open(runs_yaml) as f:
+            model = parse_yaml_raw_as(Runs, f)
 
-    @property
-    def jruns_path(self) -> Path:
-        """return the Path specified in the create->jruns config variable, or,
-        if that is empty, the `$JRUNS` environment variable, or, if `$JRUNS`
-        does not exists, return the current directory `./`.
-
-        Returns
-        -------
-        Path
-        """
-
-        if cfg.create.jruns:  # type: ignore
-            return cfg.create.jruns  # type: ignore
-        elif getenv('JRUNS'):
-            return Path(getenv('JRUNS'))  # type: ignore
-        else:
-            return Path()
+        return model.root
