@@ -1,3 +1,10 @@
+"""Submodule for handling queuing and jobs.
+
+*Duqtools* uses delayed operations for filesystem-changing operations.
+They are implemented mostly with decorators, but a function could be added directly
+to the `op_queue`.
+"""
+
 from __future__ import annotations
 
 import atexit
@@ -8,10 +15,9 @@ from inspect import signature
 from typing import Any, Callable, Optional, Sequence
 
 import click
-from pydantic import Field, validator
+from pydantic import Field, field_validator
 
 from ._logging_utils import duqlog_screen
-from .config import cfg
 from .schema import BaseModel
 
 logger = logging.getLogger(__name__)
@@ -35,10 +41,13 @@ logwarning = duqlog_screen.warning
 style = click.style
 
 
-class LongDescriptionMixin:
-    description: str
-    extra_description: Optional[str]
-    style: dict
+class LongDescription(BaseModel):
+    description: str = Field(
+        description='description of the operation to be done')
+    extra_description: Optional[str] = Field(None,
+                                             description='Extra description')
+    style: dict[str, Any] = Field(OP_STYLE,
+                                  description='Styling for op description')
 
     @property
     def long_description(self) -> str:
@@ -50,13 +59,9 @@ class LongDescriptionMixin:
         return description
 
 
-class Warning(LongDescriptionMixin):
+class Warning(LongDescription):
     """Warning item for screen log."""
-    style = NO_OP_STYLE
-
-    def __init__(self, description: str, extra_description: str):
-        self.description = description
-        self.extra_description = extra_description
+    style: dict[str, Any] = NO_OP_STYLE
 
     def __hash__(self):
         return hash((self.description, self.extra_description))
@@ -65,29 +70,28 @@ class Warning(LongDescriptionMixin):
         return hash(self) == hash(other)
 
 
-class Operation(LongDescriptionMixin, BaseModel):
+class Operation(LongDescription):
     """Operation, simple class which has a callable action.
 
-    Usually not called directly but used through Operations. has the
-    following members:
+    Usually not called directly but used through Operations.
     """
-
     quiet: bool = Field(False,
                         description='print out this operation to the screen')
-    description: str = Field(
-        description='description of the operation to be done')
+
     action: Optional[Callable] = Field(
+        None,
         description='a function which can be executed when we '
         'decide to apply this operation')
-    extra_description: Optional[str] = Field(description='Extra description')
+
     args: Optional[Sequence] = Field(
         None,
+        validate_default=True,
         description='positional arguments that have to be '
         'passed to the action')
-    style: dict[str, Any] = Field(OP_STYLE,
-                                  description='Styling for op description')
+
     kwargs: Optional[dict] = Field(
         None,
+        validate_default=True,
         description='keyword arguments that will be '
         'passed to the action')
 
@@ -104,13 +108,13 @@ class Operation(LongDescriptionMixin, BaseModel):
             self.action(*self.args, **self.kwargs)  # type: ignore
         return self
 
-    @validator('args', always=True)
+    @field_validator('args')
     def validate_args(cls, v):
         if v is None:
             v = ()
         return v
 
-    @validator('kwargs', always=True)
+    @field_validator('kwargs')
     def validate_kwargs(cls, v):
         if v is None:
             v = {}
@@ -179,7 +183,7 @@ class Operations(deque):
                     extra_description=extra_description))
 
     def put(self, item: Operation):
-        """synonym for append."""
+        """Synonym for append."""
         self.append(item)
 
     def append(self, item: Operation):  # type: ignore
@@ -213,11 +217,6 @@ class Operations(deque):
         from tqdm import tqdm
         loginfo(style('Applying Operations', **HEADER_STYLE))  # type: ignore
 
-        if cfg.quiet:
-            return self._apply_all()
-
-        print(self.n_actions)
-
         with tqdm(total=self.n_actions, position=1) as pbar:
             pbar.set_description('Progress')
 
