@@ -3,19 +3,21 @@ from __future__ import annotations
 import os
 from collections import defaultdict
 from contextlib import contextmanager
-from itertools import filterfalse, tee
 from pathlib import Path
+from textwrap import dedent
 from typing import TYPE_CHECKING, Any, Callable, Hashable, Iterable
 
-from ._types import PathLike
+from pydantic_yaml import parse_yaml_raw_as
 
 if TYPE_CHECKING:
+    from ._types import PathLike
     from .ids import ImasHandle
 
 
-def no_op(*args, **kwargs):
-    """Do nothing."""
-    pass
+def formatter(s):
+    """Dedent and remove newlines."""
+    s = dedent(s)
+    return s.replace('\n', ' ').strip()
 
 
 @contextmanager
@@ -35,7 +37,7 @@ def work_directory(path: PathLike):
         os.chdir(prev_cwd)
 
 
-def read_imas_handles_from_file(inp: PathLike, ) -> dict[str, ImasHandle]:
+def read_imas_handles_from_file(inp: PathLike) -> dict[str, ImasHandle]:
     """Read a collection of imas paths from a file.
 
     Input can be a `Runs.yaml` file `data.csv` file.
@@ -49,12 +51,10 @@ def read_imas_handles_from_file(inp: PathLike, ) -> dict[str, ImasHandle]:
     ----------
     inp : PathLike
         Name of the file to read.
-    as_dataframe : bool, optional
-        Return imas handles in a dataframe instead.
 
     Returns
     -------
-    Union[dict[str, ImasHandle], 'pd.DataFrame']
+    dict[str, ImasHandle]
         Returns a dict with the Imas handles.
 
     Raises
@@ -72,7 +72,7 @@ def read_imas_handles_from_file(inp: PathLike, ) -> dict[str, ImasHandle]:
     if inp.suffix == '.csv':
         handles = {}
         with open(inp) as f:
-            has_header = csv.Sniffer().has_header(f.read(1024))
+            has_header = csv.Sniffer().has_header(''.join(f.readlines(3)))
             f.seek(0)
 
             if not has_header:
@@ -89,9 +89,11 @@ def read_imas_handles_from_file(inp: PathLike, ) -> dict[str, ImasHandle]:
                 handles[index] = ImasHandle(**row)
 
     elif inp.name == 'runs.yaml':
-        runs = Runs.parse_file(inp)
+        with open(inp) as f:
+            runs = parse_yaml_raw_as(Runs, f)
         handles = {
-            str(run.dirname): ImasHandle.parse_obj(run.data_out)
+            str(run.dirname): ImasHandle.model_validate(run.data_out,
+                                                        from_attributes=True)
             for run in runs
         }
 
@@ -125,28 +127,3 @@ def groupby(iterable: Iterable,
         grouped[key].append(item)
 
     return grouped
-
-
-def partition(pred: Callable, iterable: Iterable) -> tuple[Iterable, Iterable]:
-    """Use a predicate to partition entries into false entries and true
-    entries.
-
-    partition(is_odd, range(10)) --> 0 2 4 6 8   and  1 3 5 7 9
-
-    From: https://docs.python.org/3/library/itertools.html
-
-    Parameters
-    ----------
-    pred : Callable
-        Filter function called on every entry in the iterable to determine
-        whether to put it in the false or true bin
-    iterable : Iterable
-        List of items to partition
-
-    Returns
-    -------
-    tuple[Iterable, Iterable]
-        Two sequences with false and true entries, respectively.
-    """
-    t1, t2 = tee(iterable)
-    return filterfalse(pred, t1), filter(pred, t2)
